@@ -2,12 +2,23 @@ package Image::PNG::Const;
 require Exporter;
 @ISA = qw(Exporter);
 @EXPORT_OK = qw/
+PNG_DISPOSE_OP_NONE
+PNG_DISPOSE_OP_BACKGROUND
+PNG_DISPOSE_OP_PREVIOUS
+PNG_BLEND_OP_SOURCE
+PNG_BLEND_OP_OVER
 PNG_TEXT_COMPRESSION_NONE_WR
 PNG_TEXT_COMPRESSION_zTXt_WR
 PNG_TEXT_COMPRESSION_NONE
 PNG_TEXT_COMPRESSION_zTXt
 PNG_ITXT_COMPRESSION_NONE
 PNG_ITXT_COMPRESSION_zTXt
+PNG_HAVE_IHDR
+PNG_HAVE_PLTE
+PNG_AFTER_IDAT
+PNG_FP_1
+PNG_FP_HALF
+PNG_FP_MIN
 PNG_COLOR_MASK_PALETTE
 PNG_COLOR_MASK_COLOR
 PNG_COLOR_MASK_ALPHA
@@ -58,6 +69,8 @@ PNG_INFO_iCCP
 PNG_INFO_sPLT
 PNG_INFO_sCAL
 PNG_INFO_IDAT
+PNG_INFO_acTL
+PNG_INFO_fcTL
 PNG_TRANSFORM_IDENTITY
 PNG_TRANSFORM_STRIP_16
 PNG_TRANSFORM_STRIP_ALPHA
@@ -74,15 +87,27 @@ PNG_TRANSFORM_STRIP_FILLER
 PNG_TRANSFORM_STRIP_FILLER_BEFORE
 PNG_TRANSFORM_STRIP_FILLER_AFTER
 PNG_TRANSFORM_GRAY_TO_RGB
+PNG_TRANSFORM_EXPAND_16
+PNG_TRANSFORM_SCALE_16
 PNG_FLAG_MNG_EMPTY_PLTE
 PNG_FLAG_MNG_FILTER_64
 PNG_ALL_MNG_FEATURES
-PNG_FILLER_BEFORE
-PNG_FILLER_AFTER
-PNG_BACKGROUND_GAMMA_UNKNOWN
-PNG_BACKGROUND_GAMMA_SCREEN
-PNG_BACKGROUND_GAMMA_FILE
-PNG_BACKGROUND_GAMMA_UNIQUE
+PNG_ERROR_ACTION_NONE
+PNG_ERROR_ACTION_WARN
+PNG_ERROR_ACTION_ERROR
+PNG_RGB_TO_GRAY_DEFAULT
+PNG_ALPHA_PNG
+PNG_ALPHA_STANDARD
+PNG_ALPHA_ASSOCIATED
+PNG_ALPHA_PREMULTIPLIED
+PNG_ALPHA_OPTIMIZED
+PNG_ALPHA_BROKEN
+PNG_DEFAULT_sRGB
+PNG_GAMMA_MAC_18
+PNG_GAMMA_sRGB
+PNG_GAMMA_LINEAR
+PNG_READ_16_TO_8
+PNG_GAMMA_THRESHOLD
 PNG_CRC_DEFAULT
 PNG_CRC_ERROR_QUIT
 PNG_CRC_WARN_DISCARD
@@ -124,22 +149,7 @@ PNG_HANDLE_CHUNK_AS_DEFAULT
 PNG_HANDLE_CHUNK_NEVER
 PNG_HANDLE_CHUNK_IF_SAFE
 PNG_HANDLE_CHUNK_ALWAYS
-PNG_IO_NONE
-PNG_IO_READING
-PNG_IO_WRITING
-PNG_IO_SIGNATURE
-PNG_IO_CHUNK_HDR
-PNG_IO_CHUNK_DATA
-PNG_IO_CHUNK_CRC
-PNG_IO_MASK_OP
-PNG_IO_MASK_LOC
-PNG_HAVE_IHDR
-PNG_HAVE_PLTE
-PNG_HAVE_IDAT
-PNG_AFTER_IDAT
-PNG_HAVE_IEND
-PNG_HAVE_gAMA
-PNG_HAVE_cHRM
+PNG_INTERLACE_ADAM7_PASSES
 /;
 
 %EXPORT_TAGS = ('all' => \@EXPORT_OK);
@@ -148,12 +158,28 @@ use warnings;
 use strict;
 
 use constant {
+    SUPPORTED => 1,
+    PNG_GAMMA_THRESHOLD_FIXED => 1,
+};
+
+use constant {
+    PNG_DISPOSE_OP_NONE => 0x00,
+    PNG_DISPOSE_OP_BACKGROUND => 0x01,
+    PNG_DISPOSE_OP_PREVIOUS => 0x02,
+    PNG_BLEND_OP_SOURCE => 0x00,
+    PNG_BLEND_OP_OVER => 0x01,
     PNG_TEXT_COMPRESSION_NONE_WR => -3,
     PNG_TEXT_COMPRESSION_zTXt_WR => -2,
     PNG_TEXT_COMPRESSION_NONE => -1,
     PNG_TEXT_COMPRESSION_zTXt => 0,
     PNG_ITXT_COMPRESSION_NONE => 1,
     PNG_ITXT_COMPRESSION_zTXt => 2,
+    PNG_HAVE_IHDR => 0x01,
+    PNG_HAVE_PLTE => 0x02,
+    PNG_AFTER_IDAT => 0x08,
+    PNG_FP_1 => 100000,
+    PNG_FP_HALF => 50000,
+    PNG_FP_MIN => (-PNG_FP_MAX),
     PNG_COLOR_MASK_PALETTE => 1,
     PNG_COLOR_MASK_COLOR => 2,
     PNG_COLOR_MASK_ALPHA => 4,
@@ -204,6 +230,8 @@ use constant {
     PNG_INFO_sPLT => 0x2000,
     PNG_INFO_sCAL => 0x4000,
     PNG_INFO_IDAT => 0x8000,
+    PNG_INFO_acTL => 0x10000,
+    PNG_INFO_fcTL => 0x20000,
     PNG_TRANSFORM_IDENTITY => 0x0000,
     PNG_TRANSFORM_STRIP_16 => 0x0001,
     PNG_TRANSFORM_STRIP_ALPHA => 0x0002,
@@ -220,15 +248,27 @@ use constant {
     PNG_TRANSFORM_STRIP_FILLER_BEFORE => 0x0800,
     PNG_TRANSFORM_STRIP_FILLER_AFTER => 0x1000,
     PNG_TRANSFORM_GRAY_TO_RGB => 0x2000,
+    PNG_TRANSFORM_EXPAND_16 => 0x4000,
+    PNG_TRANSFORM_SCALE_16 => 0x8000,
     PNG_FLAG_MNG_EMPTY_PLTE => 0x01,
     PNG_FLAG_MNG_FILTER_64 => 0x04,
     PNG_ALL_MNG_FEATURES => 0x05,
-    PNG_FILLER_BEFORE => 0,
-    PNG_FILLER_AFTER => 1,
-    PNG_BACKGROUND_GAMMA_UNKNOWN => 0,
-    PNG_BACKGROUND_GAMMA_SCREEN => 1,
-    PNG_BACKGROUND_GAMMA_FILE => 2,
-    PNG_BACKGROUND_GAMMA_UNIQUE => 3,
+    PNG_ERROR_ACTION_NONE => 1,
+    PNG_ERROR_ACTION_WARN => 2,
+    PNG_ERROR_ACTION_ERROR => 3,
+    PNG_RGB_TO_GRAY_DEFAULT => (-1),
+    PNG_ALPHA_PNG => 0,
+    PNG_ALPHA_STANDARD => 1,
+    PNG_ALPHA_ASSOCIATED => 1,
+    PNG_ALPHA_PREMULTIPLIED => 1,
+    PNG_ALPHA_OPTIMIZED => 2,
+    PNG_ALPHA_BROKEN => 3,
+    PNG_DEFAULT_sRGB => -1,
+    PNG_GAMMA_MAC_18 => -2,
+    PNG_GAMMA_sRGB => 220000,
+    PNG_GAMMA_LINEAR => 100000,
+    PNG_READ_16_TO_8 => SUPPORTED,
+    PNG_GAMMA_THRESHOLD => (PNG_GAMMA_THRESHOLD_FIXED*.00001),
     PNG_CRC_DEFAULT => 0,
     PNG_CRC_ERROR_QUIT => 1,
     PNG_CRC_WARN_DISCARD => 2,
@@ -270,22 +310,7 @@ use constant {
     PNG_HANDLE_CHUNK_NEVER => 1,
     PNG_HANDLE_CHUNK_IF_SAFE => 2,
     PNG_HANDLE_CHUNK_ALWAYS => 3,
-    PNG_IO_NONE => 0x0000,
-    PNG_IO_READING => 0x0001,
-    PNG_IO_WRITING => 0x0002,
-    PNG_IO_SIGNATURE => 0x0010,
-    PNG_IO_CHUNK_HDR => 0x0020,
-    PNG_IO_CHUNK_DATA => 0x0040,
-    PNG_IO_CHUNK_CRC => 0x0080,
-    PNG_IO_MASK_OP => 0x000f,
-    PNG_IO_MASK_LOC => 0x00f0,
-    PNG_HAVE_IHDR => 0x01,
-    PNG_HAVE_PLTE => 0x02,
-    PNG_HAVE_IDAT => 0x04,
-    PNG_AFTER_IDAT => 0x08,
-    PNG_HAVE_IEND => 0x10,
-    PNG_HAVE_gAMA => 0x20,
-    PNG_HAVE_cHRM => 0x40,
+    PNG_INTERLACE_ADAM7_PASSES => 7,
 };
 
 =head1 NAME
@@ -309,6 +334,16 @@ library, C<png.h>. The constants in this file are
 
 =over
 
+=item PNG_DISPOSE_OP_NONE = 0x00
+
+=item PNG_DISPOSE_OP_BACKGROUND = 0x01
+
+=item PNG_DISPOSE_OP_PREVIOUS = 0x02
+
+=item PNG_BLEND_OP_SOURCE = 0x00
+
+=item PNG_BLEND_OP_OVER = 0x01
+
 =item PNG_TEXT_COMPRESSION_NONE_WR = -3
 
 =item PNG_TEXT_COMPRESSION_zTXt_WR = -2
@@ -321,6 +356,18 @@ library, C<png.h>. The constants in this file are
 
 =item PNG_ITXT_COMPRESSION_zTXt = 2
 
+=item PNG_HAVE_IHDR = 0x01
+
+=item PNG_HAVE_PLTE = 0x02
+
+=item PNG_AFTER_IDAT = 0x08
+
+=item PNG_FP_1 = 100000
+
+=item PNG_FP_HALF = 50000
+
+=item PNG_FP_MIN = (-PNG_FP_MAX)
+
 =item PNG_COLOR_MASK_PALETTE = 1
 
 =item PNG_COLOR_MASK_COLOR = 2
@@ -421,6 +468,10 @@ library, C<png.h>. The constants in this file are
 
 =item PNG_INFO_IDAT = 0x8000
 
+=item PNG_INFO_acTL = 0x10000
+
+=item PNG_INFO_fcTL = 0x20000
+
 =item PNG_TRANSFORM_IDENTITY = 0x0000
 
 =item PNG_TRANSFORM_STRIP_16 = 0x0001
@@ -453,23 +504,47 @@ library, C<png.h>. The constants in this file are
 
 =item PNG_TRANSFORM_GRAY_TO_RGB = 0x2000
 
+=item PNG_TRANSFORM_EXPAND_16 = 0x4000
+
+=item PNG_TRANSFORM_SCALE_16 = 0x8000
+
 =item PNG_FLAG_MNG_EMPTY_PLTE = 0x01
 
 =item PNG_FLAG_MNG_FILTER_64 = 0x04
 
 =item PNG_ALL_MNG_FEATURES = 0x05
 
-=item PNG_FILLER_BEFORE = 0
+=item PNG_ERROR_ACTION_NONE = 1
 
-=item PNG_FILLER_AFTER = 1
+=item PNG_ERROR_ACTION_WARN = 2
 
-=item PNG_BACKGROUND_GAMMA_UNKNOWN = 0
+=item PNG_ERROR_ACTION_ERROR = 3
 
-=item PNG_BACKGROUND_GAMMA_SCREEN = 1
+=item PNG_RGB_TO_GRAY_DEFAULT = (-1)
 
-=item PNG_BACKGROUND_GAMMA_FILE = 2
+=item PNG_ALPHA_PNG = 0
 
-=item PNG_BACKGROUND_GAMMA_UNIQUE = 3
+=item PNG_ALPHA_STANDARD = 1
+
+=item PNG_ALPHA_ASSOCIATED = 1
+
+=item PNG_ALPHA_PREMULTIPLIED = 1
+
+=item PNG_ALPHA_OPTIMIZED = 2
+
+=item PNG_ALPHA_BROKEN = 3
+
+=item PNG_DEFAULT_sRGB = -1
+
+=item PNG_GAMMA_MAC_18 = -2
+
+=item PNG_GAMMA_sRGB = 220000
+
+=item PNG_GAMMA_LINEAR = 100000
+
+=item PNG_READ_16_TO_8 = SUPPORTED
+
+=item PNG_GAMMA_THRESHOLD = (PNG_GAMMA_THRESHOLD_FIXED*.00001)
 
 =item PNG_CRC_DEFAULT = 0
 
@@ -553,37 +628,7 @@ library, C<png.h>. The constants in this file are
 
 =item PNG_HANDLE_CHUNK_ALWAYS = 3
 
-=item PNG_IO_NONE = 0x0000
-
-=item PNG_IO_READING = 0x0001
-
-=item PNG_IO_WRITING = 0x0002
-
-=item PNG_IO_SIGNATURE = 0x0010
-
-=item PNG_IO_CHUNK_HDR = 0x0020
-
-=item PNG_IO_CHUNK_DATA = 0x0040
-
-=item PNG_IO_CHUNK_CRC = 0x0080
-
-=item PNG_IO_MASK_OP = 0x000f
-
-=item PNG_IO_MASK_LOC = 0x00f0
-
-=item PNG_HAVE_IHDR = 0x01
-
-=item PNG_HAVE_PLTE = 0x02
-
-=item PNG_HAVE_IDAT = 0x04
-
-=item PNG_AFTER_IDAT = 0x08
-
-=item PNG_HAVE_IEND = 0x10
-
-=item PNG_HAVE_gAMA = 0x20
-
-=item PNG_HAVE_cHRM = 0x40
+=item PNG_INTERLACE_ADAM7_PASSES = 7
 
 =back
 
@@ -613,7 +658,7 @@ Ben Bullock, <bkb@cpan.org>
 =head1 COPYRIGHT & LICENCE
 
 The Image::PNG package and associated files are copyright (C)
-2012 Ben Bullock.
+2013 Ben Bullock.
 
 You can use, copy, modify and redistribute Image::PNG and
 associated files under the Perl Artistic Licence or the GNU General
